#!/bin/sh

METADATA_URL="http://169.254.169.254/latest/meta-data"

r3_logger() {
  logger -t remoteit "$@"
}

r3_get_architecture() {
  uname -m
}

r3_is_ec2() {
  curl -s -m 1 "http://169.254.169.254/latest/meta-data" | /bin/sh -s >/dev/null 2>&1
  if [ $? -ne 0 ]; then
    echo 1
  else
    echo 0
  fi
}

isEc2=$(r3_is_ec2)

r3_get_name() {
  if [ $isEc2 == 1 ]; then
    curl -s $METADATA_URL/instance-id | sed -e 's/-//g'
  else
    cat /sys/devices/virtual/dmi/id/product_family
  fi
}

r3_get_macaddr() {
  if [ $isEc2 == 1 ]; then
    curl -s $METADATA_URL/mac
  else
    ip link show up | grep ether | head -n 1 | awk '{print $2}'
  fi
}

r3_get_model() {
  if [ $isEc2 == 1 ]; then
    curl -s $METADATA_URL/instance-type | sed -e 's/\.//g'
  else
    cat /sys/devices/virtual/dmi/id/product_family
  fi
}

r3_get_serial() {
  if [ $isEc2 == 1 ]; then
    curl -s $METADATA_URL/instance-id | sed -e 's/-//g'
  else
    sudo cat /sys/devices/virtual/dmi/id/product_serial
  fi
}

r3_get_identity() {
  r3_get_macaddr
}

r3_get_manufacturer() {
  echo 34304
}

r3_get_platform() {
  if [ $isEc2 == 1 ]; then
    echo 1185
  else
    echo 769
  fi
}

r3_get_metadata() {
  jq -n \
    --arg version "$VERSION" \
    --arg macAddress "$(r3_get_macaddr)" \
    --arg model "$(r3_get_model)" \
    --arg serialNum "$(r3_get_serial)" \
    '{$version, $macAddress, $model, $serialNum}'
}
